// VinciaRootSettings.h is a part of the VINCIA plug-in to the PYTHIA 8 generator.
// Copyright (C) 2013 P. Skands
// VINCIA is licenced under the GNU GPL version 2.
// Please respect the MCnet Guidelines for Event Generator Authors and Users, 
//               http://www.montecarlonet.org/GUIDELINES

// This file contains header information for the Vincia ROOT utilities

#ifndef VINCIAROOTSETTINGS_H
#define VINCIAROOTSETTINGS_H

// Include specific ROOT headers 

// Main ROOT header
#include "TROOT.h"
// 1D and 2D histograms
#include "TH1.h"
#include "TH2.h"
#include "TGraphAsymmErrors.h"
#include "TPaveStats.h"
#include "TLatex.h"
#include "TLegend.h"
#include "TLegendEntry.h"
#include "TLine.h"
// Widget windows
#include "TCanvas.h"
#include "TApplication.h"
// To read/write files
#include "TDirectory.h"
#include "TFile.h"

// Standard Libraries (same as in PYTHIA 8)
// Stdlib header files for mathematics.
#include <cmath>
#include <cstdlib>

// Stdlib header files for strings and containers.
#include <string>
#include <vector>
#include <map>
#include <deque>
#include <set>

// Stdlib header file for input and output.
#include <iostream>
#include <iomanip>
#include <fstream>
#include <sstream>

// Define pi if not yet done.
#ifndef M_PI
#define M_PI 3.1415926535897932385
#endif

// By this declaration you do not need to use std:: qualifier everywhere.
using namespace std;

// Put all the rest in Vincia namespace

namespace Vincia {
  
  // ------------------------------------------------------------------------
  // class VRsettings
  // Contains global settings for the VinciaRoot interface

  class VRsettings {

  public:

    // Constructor
    VRsettings() : isInitApp(false), logY(false), 
      normalize(true), showRatioPad(true), showRelUncPads(true), 
      verbose(1), optStat(1101), sigmaStat(2.), normFac(1.),
      MCnames(" "), signature("V I N C I A R O O T") { legend.resize(0); };
    
    // Data members
    bool isInitApp;
    bool logY, normalize;
    bool showRatioPad, showRelUncPads;
    int verbose, optStat;
    double sigmaStat, normFac;
    string MCnames, signature;
    vector<string> legend;

  };
  
}

#endif
